@@ -3,7 +3,7 @@ function(code, only.args = FALSE, location = FALSE) {
 	# Get a call tip, given a part of the code
 	# Extract the last variable name, given it is either at the end, or terminated by '('
 	code <- sub(" *\\($", "", code[1])
-	pos <- regexpr("[a-zA-Z0-9_\\.]+$", code)
+	pos <- regexpr("[a-zA-Z0-9_\\.]+$", code, useBytes = TRUE)
 	code <- substring(code, pos)
 
 	# Get the corresponding Call Tip
